@@ -1,6 +1,14 @@
+import logging
 from typing import Optional, Any
 
-from pydantic import BaseModel, BaseSettings
+from pydantic import (BaseModel,  # pylint: disable=no-name-in-module
+                      BaseSettings)
+
+logger = logging.getLogger(__name__)
+
+"""
+user config -> directory config -> options
+"""
 
 
 class Settings(BaseSettings):
@@ -10,7 +18,9 @@ class Settings(BaseSettings):
     api_get: str = "/api/"
     debug: bool = False
     verbose: bool = False
-    config: Optional[str] = ".token_auth_cli_config.toml"
+    show_settings: bool = True
+    confirm_settings: bool = True
+    store: bool = False
 
     class Config:
         env_prefix = "TOKEN_AUTH_CLI_SETTINGS_"
@@ -20,4 +30,5 @@ class Settings(BaseSettings):
 
 class App(BaseModel):
     settings: Settings
+    config: str
     session: Optional[Any] = None
